/*
 * This file is part of Advanced ABX
 *
 * Copyright 2010 Christian Uebber
 *
 * Advanced ABX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2, as
 * published by the Free Software Foundation.
 *
 * Advanced ABX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Advanced ABX.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.uebber.sound.lib;

import org.junit.After;
import org.junit.Test;

import javax.sound.sampled.AudioInputStream;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.LineEvent;
import javax.sound.sampled.LineListener;

/**
 * Test class for ArrayClip.
 *
 * @author Christian Uebber
 */
public class ArrayClipTest {

    private ArrayClip clip;

    @After
    public void tearDown() throws Exception {
        if (clip != null) clip.close();
    }

    @Test
    public void testLoop() throws Exception {
        initClip("48000-16-stereo-sweep-loop.wav");
        printMessage("You should hear a up and down sweep, looped 3 times, without clicking in between.");
        clip.loop(2);
        Thread.sleep(clip.getMicrosecondLength() / 1000 * 3 + 1000);

        initClip("48000-16-stereo-beeps-loop.wav");
        clip.setLoopPoints(72000, 120000);
        printMessage("You should hear: low, mid, high, short mid, short high, short mid, long high.");
        clip.loop(2);
        Thread.sleep(clip.getMicrosecondLength() / 1000 * 2 + 1000);
        clip.stop();

        clip.setFramePosition(48001);
        clip.setLoopPoints(0, 24000);
        printMessage("You should hear: mid, high.");
        clip.loop(100);
        Thread.sleep(clip.getMicrosecondLength() / 1000 + 1000);
    }

    private void printMessage(String message) {
        System.out.println("*************************************************************************************");
        System.out.println("");
        System.out.println(" " + message);
        System.out.println("");
        System.out.println("*************************************************************************************");
    }

    private void initClip(String filename) throws Exception {
        if (clip != null)
            clip.close();
        AudioInputStream stream = AudioSystem.getAudioInputStream(this.getClass().getResource(filename));
        clip = new SwitchableArrayClip();
        clip.open(stream);
        clip.addLineListener(new LineListener() {
            @Override
            public void update(LineEvent event) {
                System.out.println(event);
            }
        });
        System.out.println("Successfully opened line for: " + stream.getFormat());
        stream.close();
    }
}
