/*
 * This file is part of Advanced ABX
 *
 * Copyright 2010 Christian Uebber
 *
 * Advanced ABX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2, as
 * published by the Free Software Foundation.
 *
 * Advanced ABX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Advanced ABX.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.uebber.sound.lib;

import org.junit.After;
import org.junit.Test;

import javax.sound.sampled.AudioInputStream;
import javax.sound.sampled.AudioSystem;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Test class for SwitchableArrayClip
 *
 * @author Christian Uebber
 */
public class SwitchableArrayClipTest {

    private SwitchableArrayClip clip;

    public SwitchableArrayClipTest() {
        Logger.getLogger("lib.SwitchableArrayClip").setLevel(Level.ALL);
//        Logger.getLogger("").getHandlers()[0].setLevel(Level.ALL);
    }

    @After
    public void tearDown() throws Exception {
        if (clip != null)
            clip.close();
    }

    @Test
    public void testSwitchStream() throws Exception {
        initClip("48000-16-stereo-sine-loop.wav", "48000-16-stereo-sine-inverted-loop.wav");
        clip.loop(9);
        int timeSlept = 0;
        int nextStream = 0;
        while (timeSlept <= 20000) {
            Thread.sleep(1000);
            timeSlept += 1000;
            nextStream = nextStream == 0 ? 1 : 0;
            clip.switchStream(nextStream);
        }
        Thread.sleep(1000);
    }

    private void initClip(String... filenames) throws Exception {

        if (clip != null)
            clip.close();

        clip = new SwitchableArrayClip();

        AudioInputStream mainStream = AudioSystem.getAudioInputStream(this.getClass().getResource(filenames[0]));

        clip.open(mainStream);

        mainStream.close();

        AudioInputStream[] otherStreams = new AudioInputStream[filenames.length - 1];

        for (int i = 0; i < filenames.length - 1; i++) {
            otherStreams[i] = AudioSystem.getAudioInputStream(this.getClass().getResource(filenames[i + 1]));
        }

        clip.addStreams(otherStreams);

        for (AudioInputStream stream : otherStreams) {
            stream.close();
        }
    }
}
